==> nextcloud-11.0.2.tgz: nextcloud/apps/gallery/l10n/it.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleria",
    "There was a problem reading files from this album" : "Si è verificato un problema durante la lettura dei file da questo album.",
    "Aborting preview. Could not find the file" : "Anteprima interrotta. Impossibile trovare il file",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "No compatible server found at {remote}" : "Nessun server compatibile trovato su {remote}",
    "Invalid server url" : "URL del server non valido",
    "Gallery view" : "Galleria",
    "Could not load the description" : "Impossibile caricare la descrizione",
    "Could not load the description: " : "Impossibile caricare la descrizione:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Impossibile caricare l'avviso di copyright:",
    "Copyright notice" : "Avviso di copyright",
    "Link to copyright document" : "Collegamento al documento di copyright",
    "This application may not work properly on your browser." : "Questa applicazione potrebbe non funzionare correttamente con il tuo browser.",
    "For an improved experience, please install one of the following alternatives" : "Per un'esperienza più completa, installa una delle seguenti alternative",
    "Your browser is not supported!" : "Il tuo browser non è supportato!",
    "please install one of the following alternatives" : "installa una delle seguenti alternative",
    "Album cannot be shown" : "L'album non può essere mostrato",
    "No media files found" : "Nessun file multimediale trovato",
    "Upload pictures in the files app to display them here" : "Carica le immagini nell'applicazione dei file per visualizzarle qui.",
    "Upload new files via drag and drop or by using the [+] button above" : "Carica nuovi file trascinandoli e rilasciandoli o utilizzando il pulsante [+] in alto",
    "Configuration error" : "Errore di configurazione",
    "New" : "Nuovo",
    "Hide Album" : "Nascondi album",
    "Could not hide album" : "Impossibile nascondere l'album",
    "Error loading slideshow template" : "Errore durante il caricamento del modello di presentazione",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Errore!</strong> Impossibile generare un'anteprima di questo file.<br>Vai alla diapositiva successiva mentre rimuoviamo questa immagine della presentazione",
    "Next" : "Avanti",
    "Play" : "Riproduci",
    "Pause" : "Pausa",
    "Previous" : "Indietro",
    "Close" : "Chiudi",
    "Download" : "Scarica",
    "Toggle background" : "Commuta lo sfondo",
    "Delete" : "Elimina",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Upload" : "Carica",
    "Error" : "Errore",
    "Error while sharing" : "Errore durante la condivisione",
    "Error while unsharing" : "Errore durante la rimozione della condivisione",
    "Error while changing permissions" : "Errore durante la modifica dei permessi",
    "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
    "Shared with you by {owner}" : "Condiviso con te da {owner}",
    "Share with users or groups …" : "Condividi con utenti o gruppi...",
    "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
    "Share" : "Condividi",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Condividi con persone su altri server utilizzando il loro ID di cloud federata nomeutente@esempio.com/nextcloud",
    "Share link" : "Condividi collegamento",
    "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
    "Link" : "Collegamento",
    "Password protect" : "Proteggi con password",
    "Password" : "Password",
    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
    "Allow editing" : "Consenti la modifica",
    "Email link to person" : "Invia collegamento via email",
    "Send" : "Invia",
    "Set expiration date" : "Imposta data di scadenza",
    "Expiration" : "Scadenza",
    "Expiration date" : "Data di scadenza",
    "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
    "Adding user..." : "Aggiunta utente in corso...",
    "group" : "gruppo",
    "remote" : "remota",
    "Resharing is not allowed" : "La ri-condivisione non è consentita",
    "Error while retrieving shares" : "Errore durante il recupero delle condivisioni",
    "Unshare" : "Rimuovi condivisione",
    "notify by email" : "notifica tramite email",
    "can share" : "può condividere",
    "can edit" : "può modificare",
    "access control" : "controllo d'accesso",
    "create" : "crea",
    "change" : "cambia",
    "delete" : "elimina",
    "Password protected" : "Protetta da password",
    "Error unsetting expiration date" : "Errore durante la rimozione della data di scadenza",
    "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
    "Sending ..." : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Warning" : "Avviso",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Sort by date" : "Ordina per data",
    "Sort by name" : "Ordina per nome",
    "Cancel upload" : "Annulla caricamento",
    "Album information" : "Informazioni sull'album",
    "File list" : "Elenco dei file",
    "Sorry, this file could not be found." : "Spiacenti, questo file non può essere trovato.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the wrong file ID was provided" : "è stato fornito l'ID del file errato",
    "the file was removed" : "il file è stato rimosso",
    "the file is corrupt" : "il file è danneggiato",
    "the encryption key is missing" : "manca la chiave di cifratura",
    "Here is the error message returned by the server: " : "Ecco il messaggio di errore restituito dal server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Per ulteriori informazioni, contatta il tuo amministratore di Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Spiacenti, ma il server non può completare la tua richiesta.",
    "Possible reasons for the problem:" : "Possibili cause del problema:",
    "a conflicting app was installed" : "è stata installata un'applicazione che causa un conflitto",
    "a required component is missing or was disconnected" : "un componente richiesto è mancante o è stato disconnesso",
    "the filesystem is not readable" : "il filesystem non è leggibile",
    "For more information, please contact your friendly ownCloud administrator." : "Per ulteriori informazioni, contatta il tuo amministratore di ownCloud.",
    "Sorry, this link doesn't seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link has expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more information, please ask the person who has sent you this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your Nextcloud" : "Aggiungi al tuo Nextcloud",
    "Picture view" : "Vista immagini"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/it.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galleria",
    "There was a problem reading files from this album" : "Si è verificato un problema durante la lettura dei file da questo album.",
    "Aborting preview. Could not find the file" : "Anteprima interrotta. Impossibile trovare il file",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "No compatible server found at {remote}" : "Nessun server compatibile trovato su {remote}",
    "Invalid server url" : "URL del server non valido",
    "Could not load the description" : "Impossibile caricare la descrizione",
    "Could not load the description: " : "Impossibile caricare la descrizione:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Impossibile caricare l'avviso di copyright:",
    "Copyright notice" : "Avviso di copyright",
    "Link to copyright document" : "Collegamento al documento di copyright",
    "This application may not work properly on your browser." : "Questa applicazione potrebbe non funzionare correttamente con il tuo browser.",
    "For an improved experience, please install one of the following alternatives" : "Per un'esperienza più completa, installa una delle seguenti alternative",
    "Your browser is not supported!" : "Il tuo browser non è supportato!",
    "please install one of the following alternatives" : "installa una delle seguenti alternative",
    "Album cannot be shown" : "L'album non può essere mostrato",
    "No media files found" : "Nessun file multimediale trovato",
    "Upload pictures in the Files app to display them here" : "Carica le immagini nell'applicazione dei file per visualizzarle qui",
    "Upload new files via drag and drop or by using the [+] button above" : "Carica nuovi file trascinandoli e rilasciandoli o utilizzando il pulsante [+] in alto",
    "Configuration error" : "Errore di configurazione",
    "New" : "Nuovo",
    "Hide Album" : "Nascondi album",
    "Could not hide album" : "Impossibile nascondere l'album",
    "Error loading slideshow template" : "Errore durante il caricamento del modello di presentazione",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Errore!</strong> Impossibile generare un'anteprima di questo file.<br>Vai alla diapositiva successiva mentre rimuoviamo questa immagine della presentazione",
    "Next" : "Avanti",
    "Play" : "Riproduci",
    "Pause" : "Pausa",
    "Previous" : "Indietro",
    "Close" : "Chiudi",
    "Download" : "Scarica",
    "Toggle background" : "Commuta lo sfondo",
    "Delete" : "Elimina",
    "Share" : "Condividi",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file consentito",
    "Upload" : "Carica",
    "Error" : "Errore",
    "Error while sharing" : "Errore durante la condivisione",
    "Error while unsharing" : "Errore durante la rimozione della condivisione",
    "Error while changing permissions" : "Errore durante la modifica dei permessi",
    "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
    "Shared with you by {owner}" : "Condiviso con te da {owner}",
    "Share with users or groups …" : "Condividi con utenti o gruppi...",
    "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Condividi con persone su altri server utilizzando il loro ID di cloud federata nomeutente@esempio.com/nextcloud",
    "Share link" : "Condividi collegamento",
    "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
    "Link" : "Collegamento",
    "Password protect" : "Proteggi con password",
    "Password" : "Password",
    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
    "Allow editing" : "Consenti la modifica",
    "Email link to person" : "Invia collegamento via email",
    "Send" : "Invia",
    "Set expiration date" : "Imposta data di scadenza",
    "Expiration" : "Scadenza",
    "Expiration date" : "Data di scadenza",
    "This list is maybe truncated - please refine your search term to see more results." : "Questa lista potrebbe essere troncata - correggi i termini di ricerca per molti altri risultati.",
    "No users or groups found for {search}" : "Nessun utente o gruppo trovato per {search}",
    "No users found for {search}" : "Nessun utente trovato per {search}",
    "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
    "Adding user..." : "Aggiunta utente in corso...",
    "group" : "gruppo",
    "remote" : "remota",
    "Resharing is not allowed" : "La ri-condivisione non è consentita",
    "Error while retrieving shares" : "Errore durante il recupero delle condivisioni",
    "Unshare" : "Rimuovi condivisione",
    "notify by email" : "notifica tramite email",
    "can share" : "può condividere",
    "can edit" : "può modificare",
    "access control" : "controllo d'accesso",
    "create" : "crea",
    "change" : "cambia",
    "delete" : "elimina",
    "Password protected" : "Protetta da password",
    "Error unsetting expiration date" : "Errore durante la rimozione della data di scadenza",
    "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
    "Sending…" : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Warning" : "Avviso",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Sort by name" : "Ordina per nome",
    "Sort by date" : "Ordina per data",
    "Cancel upload" : "Annulla caricamento",
    "Album information" : "Informazioni sull'album",
    "File list" : "Elenco dei file",
    "Sorry, this file could not be found." : "Spiacenti, questo file non può essere trovato.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the wrong file ID was provided" : "è stato fornito l'ID del file errato",
    "the file was removed" : "il file è stato rimosso",
    "the file is corrupt" : "il file è danneggiato",
    "the encryption key is missing" : "manca la chiave di cifratura",
    "Here is the error message returned by the server: " : "Ecco il messaggio di errore restituito dal server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Per ulteriori informazioni, contatta il tuo amministratore di Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Spiacenti, ma il server non può completare la tua richiesta.",
    "Possible reasons for the problem:" : "Possibili cause del problema:",
    "a conflicting app was installed" : "è stata installata un'applicazione che causa un conflitto",
    "a required component is missing or was disconnected" : "un componente richiesto è mancante o è stato disconnesso",
    "the filesystem is not readable" : "il filesystem non è leggibile",
    "Sorry, this link doesn't seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link has expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more information, please ask the person who has sent you this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your Nextcloud" : "Aggiungi al tuo Nextcloud",
    "Picture view" : "Vista immagini",
    "Gallery view" : "Galleria",
    "Sending ..." : "Invio in corso..."
},
"nplurals=2; plural=(n != 1);");
